@@ -27,13 +27,6 @@
 #define ENC_WIDE 2
 #define ENC_NARROW 3
 
-#ifndef Py_RETURN_TRUE
-/* For python2.3 */
-#define Py_RETURN_TRUE return Py_INCREF(Py_True), Py_True
-#define Py_RETURN_FALSE return Py_INCREF(Py_False), Py_False
-#endif
-
-
 
 static int widths_len = 2*38;
 static const long int widths[] = {
